{% extends "user/index.html" %}
{% block title %}Password edited successfully{% endblock %}
{% block wrapper %}
<h1>Password Edit</h1>
<h2 class="text-success">Your password has been successfully updated. Test your login credentials at
    <a href="{{ SERVICE_PROVIDER_URL }}" class="btn btn-danger btn-sm" role="button">{{ SERVICE_PROVIDER }}</a></h2>
{% endblock %}