# Generated by Django 2.0.6 on 2018-07-12 12:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0003_auto_20180710_1347'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='reset_code_expiry',
            field=models.DateTimeField(null=True),
        ),
    ]
