{% extends "user/index.html" %}
{% block title %}Create an account{% endblock %}
{% block wrapper %}
    <div class="row">
        <h2>You are registering to the {{ IDP_NAME }}</h2>
    </div>
    {% if form.errors %}
    <div class="alert alert-danger">
        <b>{{ form.errors|length}}</b> error{{ form.errors|length|pluralize:" was,s were" }} found! Please fix.
        {{ form.non_field_errors }}
        <ul>
		    {% for field in form %}
			{% if field.errors %}<li><i>{{ field.label }}</i>: {{ field.errors|striptags }}</li>{% endif %}
			{% endfor %}
		</ul>
    </div>
    {% endif %}

    <div class="row">
        {% load crispy_forms_tags %}
        {% crispy form %}
    </div>
</div>
{% endblock %}