{% extends "user/index.html" %}
{% block title %}Password reset sent{% endblock %}
{% block wrapper %}
<h1>Email sent</h1>
<h2 class="text-success">A link has been sent to the email you provided. Follow the instructions</h2>
{% endblock %}