# Generated by Django 2.0.6 on 2018-07-10 13:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0002_userregistrationrecord'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='address',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='country',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='designation',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='gender',
            field=models.CharField(blank=True, max_length=10),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='organization',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='phone',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='reset_code_expiry',
            field=models.DateTimeField(blank=True),
        ),
        migrations.AlterField(
            model_name='userregistrationrecord',
            name='title',
            field=models.CharField(blank=True, max_length=30),
        ),
    ]
