{% extends "user/index.html" %}
{% block title %}Account creation success!{% endblock %}
{% block wrapper %}
<h1>Successfully registered!</h1>
<h2 class="text-success">A verification email has been sent to your account</h2>
{% endblock %}