{% extends "user/index.html" %}
{% block title %}Enter New Password{% endblock %}
{% block wrapper %}
<div class="col-md-6">
    {% if ldap_error %}
    <div class="alert alert-danger">
        {{ ldap_error }}
    </div>
    {% endif %}
    {% if form.errors %}
    <div class="alert alert-danger">
        <b>{{ form.errors|length}}</b> error{{ form.errors|length|pluralize:" was,s were" }} found! Please fix.
        {{ form.non_field_errors }}
    </div>
    {% endif %}

    <div class="row">
        {% load crispy_forms_tags %}
        {% crispy form %}
    </div>
</div>
{% endblock %}