# Generated by Django 2.0.6 on 2018-07-10 08:11

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('user', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserRegistrationRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reset_code', models.CharField(default='', max_length=255)),
                ('reset_code_active', models.BooleanField(default=False)),
                ('reset_code_expiry', models.DateTimeField()),
                ('gender', models.CharField(max_length=10)),
                ('title', models.CharField(max_length=30)),
                ('designation', models.CharField(max_length=200)),
                ('organization', models.CharField(max_length=255)),
                ('phone', models.CharField(max_length=200)),
                ('address', models.TextField()),
                ('country', models.CharField(max_length=100)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
