# Generated by Django 2.0.6 on 2018-07-17 09:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0005_auto_20180712_1308'),
    ]

    operations = [
        migrations.AddField(
            model_name='userregistrationrecord',
            name='ldap_password',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
    ]
